@@ -101,7 +101,6 @@ function behat_get_error_string($errtype) {
             break;
         case E_NOTICE:
         case E_USER_NOTICE:
-        case E_STRICT:
             $errnostr = 'Notice';
             break;
         case E_RECOVERABLE_ERROR:
@@ -133,11 +132,11 @@ function behat_error_handler($errno, $errstr, $errfile, $errline) {
         return true;
     }
 
-    // This error handler receives E_ALL | E_STRICT, running the behat test site the debug level is
+    // This error handler receives E_ALL, running the behat test site the debug level is
     // set to DEVELOPER and will always include E_NOTICE,E_USER_NOTICE... as part of E_ALL, if the current
     // error_reporting() value does not include one of those levels is because it has been forced through
     // the moodle code (see fix_utf8() for example) in that cases we respect the forced error level value.
-    $respect = array(E_NOTICE, E_USER_NOTICE, E_STRICT, E_WARNING, E_USER_WARNING, E_DEPRECATED, E_USER_DEPRECATED);
+    $respect = [E_NOTICE, E_USER_NOTICE, E_WARNING, E_USER_WARNING, E_DEPRECATED, E_USER_DEPRECATED];
     foreach ($respect as $respectable) {
 
         // If the current value does not include this kind of errors and the reported error is
@@ -219,7 +218,8 @@ function behat_clean_init_config() {
         'umaskpermissions', 'dbtype', 'dblibrary', 'dbhost', 'dbname', 'dbuser', 'dbpass', 'prefix',
         'dboptions', 'proxyhost', 'proxyport', 'proxytype', 'proxyuser', 'proxypassword',
         'proxybypass', 'pathtogs', 'pathtophp', 'pathtodu', 'aspellpath', 'pathtodot', 'skiplangupgrade',
-        'altcacheconfigpath', 'pathtounoconv', 'alternative_file_system_class', 'pathtopython'
+        'altcacheconfigpath', 'pathtounoconv', 'alternative_file_system_class', 'pathtopython',
+        'routerconfigured',
     ));
 
     // Add extra allowed settings.
@@ -233,6 +233,12 @@ function behat_clean_init_config() {
             unset($CFG->{$key});
         }
     }
+
+    // Allow email catcher settings.
+    if (defined('TEST_EMAILCATCHER_MAIL_SERVER')) {
+        $CFG->noemailever = false;
+        $CFG->smtphosts = TEST_EMAILCATCHER_MAIL_SERVER;
+    }
 }
 
 /**
@@ -243,18 +249,31 @@ function behat_clean_init_config() {
 function behat_check_config_vars() {
     global $CFG;
 
+    $moodleprefix = empty($CFG->prefix) ? '' : $CFG->prefix;
+    $behatprefix = empty($CFG->behat_prefix) ? '' : $CFG->behat_prefix;
+    $phpunitprefix = empty($CFG->phpunit_prefix) ? '' : $CFG->phpunit_prefix;
+    $behatdbname = empty($CFG->behat_dbname) ? $CFG->dbname : $CFG->behat_dbname;
+    $phpunitdbname = empty($CFG->phpunit_dbname) ? $CFG->dbname : $CFG->phpunit_dbname;
+    $behatdbhost = empty($CFG->behat_dbhost) ? $CFG->dbhost : $CFG->behat_dbhost;
+    $phpunitdbhost = empty($CFG->phpunit_dbhost) ? $CFG->dbhost : $CFG->phpunit_dbhost;
+
     // Verify prefix value.
     if (empty($CFG->behat_prefix)) {
         behat_error(BEHAT_EXITCODE_CONFIG,
             'Define $CFG->behat_prefix in config.php');
     }
-    if (!empty($CFG->prefix) and $CFG->behat_prefix == $CFG->prefix) {
+    if ($behatprefix == $moodleprefix && $behatdbname == $CFG->dbname && $behatdbhost == $CFG->dbhost) {
         behat_error(BEHAT_EXITCODE_CONFIG,
-            '$CFG->behat_prefix in config.php must be different from $CFG->prefix');
+            '$CFG->behat_prefix in config.php must be different from $CFG->prefix' .
+            ' when $CFG->behat_dbname and $CFG->behat_host are not set or when $CFG->behat_dbname equals $CFG->dbname' .
+            ' and $CFG->behat_dbhost equals $CFG->dbhost');
     }
-    if (!empty($CFG->phpunit_prefix) and $CFG->behat_prefix == $CFG->phpunit_prefix) {
+    if ($phpunitprefix !== '' && $behatprefix == $phpunitprefix && $behatdbname == $phpunitdbname &&
+            $behatdbhost == $phpunitdbhost) {
         behat_error(BEHAT_EXITCODE_CONFIG,
-            '$CFG->behat_prefix in config.php must be different from $CFG->phpunit_prefix');
+            '$CFG->behat_prefix in config.php must be different from $CFG->phpunit_prefix' .
+            ' when $CFG->behat_dbname equals $CFG->phpunit_dbname' .
+            ' and $CFG->behat_dbhost equals $CFG->phpunit_dbhost');
     }
 
     // Verify behat wwwroot value.
@@ -340,7 +359,7 @@ function behat_is_test_site() {
  * Fix variables for parallel behat testing.
  * - behat_wwwroot = behat_wwwroot{behatrunprocess}
  * - behat_dataroot = behat_dataroot{behatrunprocess}
- * - behat_prefix = behat_prefix.{behatrunprocess}_ (For oracle it will be firstletter of prefix and behatrunprocess)
+ * - behat_prefix = behat_prefix.{behatrunprocess}
  **/
 function behat_update_vars_for_process() {
     global $CFG;
@@ -371,14 +390,8 @@ function behat_update_vars_for_process() {
         }
 
         // Set behat_prefix for db, just suffix run process number, to avoid max length exceed.
-        // For oracle only 2 letter prefix is possible.
         // NOTE: This will not work for parallel process > 9.
-        if ($CFG->dbtype === 'oci') {
-            $CFG->behat_prefix = substr($CFG->behat_prefix, 0, 1);
-            $CFG->behat_prefix .= "{$behatrunprocess}";
-        } else {
-            $CFG->behat_prefix .= "{$behatrunprocess}_";
-        }
+        $CFG->behat_prefix .= "{$behatrunprocess}_";
 
         if (!empty($CFG->behat_parallel_run[$behatrunprocess - 1])) {
             // Override allowed config vars.
@@ -400,7 +413,9 @@ function behat_update_vars_for_process() {
 function behat_is_requested_url($url) {
 
     $parsedurl = parse_url($url . '/');
-    $parsedurl['port'] = isset($parsedurl['port']) ? $parsedurl['port'] : 80;
+    if (!isset($parsedurl['port'])) {
+        $parsedurl['port'] = ($parsedurl['scheme'] === 'https') ? 443 : 80;
+    }
     $parsedurl['path'] = rtrim($parsedurl['path'], '/');
 
     // Removing the port.
