@@ -64,7 +64,8 @@ final class get_join_url_test extends \externallib_advanced_testcase {
     /**
      * Test execute API CALL with no instance
      */
-    public function test_execute_no_instance() {
+    public function test_execute_no_instance(): void {
+        $this->resetAfterTest();
         $this->expectExceptionMessageMatches('/No such instance.*/');
         $joinurl = $this->get_join_url(1234, 5678);
 
@@ -76,7 +77,7 @@ final class get_join_url_test extends \externallib_advanced_testcase {
     /**
      * Test execute API CALL without login
      */
-    public function test_execute_without_login() {
+    public function test_execute_without_login(): void {
         $this->resetAfterTest();
 
         $course = $this->getDataGenerator()->create_course();
@@ -112,7 +113,7 @@ final class get_join_url_test extends \externallib_advanced_testcase {
     /**
      * Test execute API CALL with invalid login
      */
-    public function test_execute_with_invalid_login() {
+    public function test_execute_with_invalid_login(): void {
         $this->resetAfterTest();
 
         $generator = $this->getDataGenerator();
@@ -130,7 +131,7 @@ final class get_join_url_test extends \externallib_advanced_testcase {
     /**
      * When login as a student
      */
-    public function test_execute_with_valid_login() {
+    public function test_execute_with_valid_login(): void {
         $this->resetAfterTest();
 
         $generator = $this->getDataGenerator();
@@ -159,7 +160,7 @@ final class get_join_url_test extends \externallib_advanced_testcase {
     /**
      * Check that URL are different depending on the group.
      */
-    public function test_execute_with_group() {
+    public function test_execute_with_group(): void {
         $this->resetAfterTest();
 
         $generator = $this->getDataGenerator();
@@ -197,7 +198,7 @@ final class get_join_url_test extends \externallib_advanced_testcase {
     /**
      * Check that we return the same URL once meeting is started.
      */
-    public function test_execute_with_same_url() {
+    public function test_execute_with_same_url(): void {
         $this->resetAfterTest();
 
         $generator = $this->getDataGenerator();
@@ -231,7 +232,7 @@ final class get_join_url_test extends \externallib_advanced_testcase {
     /**
      * Check that we return the same URL once meeting is started.
      */
-    public function test_user_limit() {
+    public function test_user_limit(): void {
         $this->resetAfterTest();
         set_config('bigbluebuttonbn_userlimit_editable', true);
         $generator = $this->getDataGenerator();
